/**
 * Console logger
 * @abstract
 * @memberof module:apeman-commons-logging/lib
 * @inner
 * @constructor ConsoleLogger
 * @param {object} config - Logger configuration.
 * @param {number} config.indent - Indent depth for message.
 */

"use strict";

var extend = require('extend'),
    Colorprint = require('colorprint/lib/colorprint'),
    MessageFormatter = require('./message_formatter');

/** @lends ConsoleLogger */
function ConsoleLogger() {
    var s = this;
    s.init.apply(s, arguments);
}

ConsoleLogger.prototype = new Colorprint(
    /** @lends Logger.prototype */
    {
        /** @constructs Logger */
        init: function (config) {
            var s = this;
            extend(s, config);
        },
        /**
         * Indent for log message.
         */
        indent: 0,
        /**
         * Log verbose or not.
         */
        verbose: false,
        _format: function () {
            var s = this;
            var formatter = new MessageFormatter();
            var msg = Colorprint.prototype._format.apply(s, arguments);
            return formatter.indent(msg, s.indent);
        }
    }
);

/**
 * Define a new logger.
 * @param property
 */
ConsoleLogger.define = function (property) {
    function DefinedLogger() {
        var s = this;
        s.init.apply(s, arguments);
    }

    DefinedLogger.prototype = new ConsoleLogger(property);

    return DefinedLogger;
};

module.exports = ConsoleLogger;